==> zio-aws-elasticsearch_2.12-5.17.155.1-sources.jar: zio/aws/elasticsearch/model/CompatibleVersionsMap.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.ElasticsearchVersionString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CompatibleVersionsMap(
    sourceVersion: Option[ElasticsearchVersionString] = None,
    targetVersions: Option[Iterable[ElasticsearchVersionString]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap = {
    import CompatibleVersionsMap.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
      .builder()
      .optionallyWith(
        sourceVersion.map(value =>
          ElasticsearchVersionString.unwrap(value): java.lang.String
        )
      )(_.sourceVersion)
      .optionallyWith(
        targetVersions.map(value =>
          value.map { item =>
            ElasticsearchVersionString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.targetVersions)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.CompatibleVersionsMap.ReadOnly =
    zio.aws.elasticsearch.model.CompatibleVersionsMap.wrap(buildAwsValue())
}
object CompatibleVersionsMap {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.CompatibleVersionsMap =
      zio.aws.elasticsearch.model.CompatibleVersionsMap(
        sourceVersion.map(value => value),
        targetVersions.map(value => value)
      )
    def sourceVersion: Option[ElasticsearchVersionString]
    def targetVersions: Option[List[ElasticsearchVersionString]]
    def getSourceVersion: ZIO[Any, AwsError, ElasticsearchVersionString] =
      AwsError.unwrapOptionField("sourceVersion", sourceVersion)
    def getTargetVersions
        : ZIO[Any, AwsError, List[ElasticsearchVersionString]] =
      AwsError.unwrapOptionField("targetVersions", targetVersions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
  ) extends zio.aws.elasticsearch.model.CompatibleVersionsMap.ReadOnly {
    override val sourceVersion: Option[ElasticsearchVersionString] = scala
      .Option(impl.sourceVersion())
      .map(value =>
        zio.aws.elasticsearch.model.primitives.ElasticsearchVersionString(value)
      )
    override val targetVersions: Option[List[ElasticsearchVersionString]] =
      scala
        .Option(impl.targetVersions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.primitives
              .ElasticsearchVersionString(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
  ): zio.aws.elasticsearch.model.CompatibleVersionsMap.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-elasticsearch_2.13-5.20.22.1-sources.jar: zio/aws/elasticsearch/model/CompatibleVersionsMap.scala <==
package zio.aws.elasticsearch.model
import zio.aws.elasticsearch.model.primitives.ElasticsearchVersionString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CompatibleVersionsMap(
    sourceVersion: Optional[ElasticsearchVersionString] = Optional.Absent,
    targetVersions: Optional[Iterable[ElasticsearchVersionString]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap = {
    import CompatibleVersionsMap.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
      .builder()
      .optionallyWith(
        sourceVersion.map(value =>
          ElasticsearchVersionString.unwrap(value): java.lang.String
        )
      )(_.sourceVersion)
      .optionallyWith(
        targetVersions.map(value =>
          value.map { item =>
            ElasticsearchVersionString.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.targetVersions)
      .build()
  }
  def asReadOnly: zio.aws.elasticsearch.model.CompatibleVersionsMap.ReadOnly =
    zio.aws.elasticsearch.model.CompatibleVersionsMap.wrap(buildAwsValue())
}
object CompatibleVersionsMap {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticsearch.model.CompatibleVersionsMap =
      zio.aws.elasticsearch.model.CompatibleVersionsMap(
        sourceVersion.map(value => value),
        targetVersions.map(value => value)
      )
    def sourceVersion: Optional[ElasticsearchVersionString]
    def targetVersions: Optional[List[ElasticsearchVersionString]]
    def getSourceVersion: ZIO[Any, AwsError, ElasticsearchVersionString] =
      AwsError.unwrapOptionField("sourceVersion", sourceVersion)
    def getTargetVersions
        : ZIO[Any, AwsError, List[ElasticsearchVersionString]] =
      AwsError.unwrapOptionField("targetVersions", targetVersions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
  ) extends zio.aws.elasticsearch.model.CompatibleVersionsMap.ReadOnly {
    override val sourceVersion: Optional[ElasticsearchVersionString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.sourceVersion())
        .map(value =>
          zio.aws.elasticsearch.model.primitives
            .ElasticsearchVersionString(value)
        )
    override val targetVersions: Optional[List[ElasticsearchVersionString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetVersions())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.primitives
              .ElasticsearchVersionString(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.CompatibleVersionsMap
  ): zio.aws.elasticsearch.model.CompatibleVersionsMap.ReadOnly = new Wrapper(
    impl
  )
}
